# DuckDB adapter for VeighNa Evo

<p align="center">
  <img src ="https://vnpy.oss-cn-shanghai.aliyuncs.com/vnpy-logo.png"/>
</p>

<p align="center">
    <img src ="https://img.shields.io/badge/version-1.0.0-blueviolet.svg"/>
    <img src ="https://img.shields.io/badge/platform-windows|linux|macos-yellow.svg"/>
    <img src ="https://img.shields.io/badge/python-3.10|3.11|3.12-blue.svg" />
    <img src ="https://img.shields.io/github/license/vnpy/vnpy.svg?color=orange"/>
</p>

## Introduction

This database adapter is designed specifically for VeighNa Evo.

## Install

Users can easily install ``vnpy_duckdb`` by pip according to the following command.

```
pip install vnpy_duckdb
```

Also, users can install ``vnpy_duckdb`` using the source code. Clone the repository and install as follows:

```
git clone https://github.com/veighna-global/vnpy_duckdb.git && cd vnpy_duckdb

python setup.py install
```
